# Contributing resources

Here you can find resources about the contributing workflow, governance of the
project and the onboarding of new contributors.

## For contributors

- [Contributing guide](./contributing)
- [Contributing documentation](./documentation/index)
- [Translations](./translations)
- [Testing](./testing)
- [Profiling](./profiling)
- [Benchmarks](./benchmarks)

## For core developers

- [Core Developer guide](./core_dev_guide)
- [Release guide](./release)
